sequencetools.partition_sequence_by_counts
==========================================

.. autofunction:: abjad.tools.sequencetools.partition_sequence_by_counts.partition_sequence_by_counts
   :noindex:
